/* vim: set sw=8 ts=8 si et: */
#ifndef H_CONFIG
#define H_CONFIG 1
/* This is a general configuration file. It read by all programs. */

/*-------------*/
#if defined __USE_BSD || defined __USE_ISOC9X || defined __USE_UNIX98
#define USESNPRINTF 1
#endif
/*-------------*/
/* This string can be read by the Unix program "what" */
#define VERINFO "@(#)Version: 2.10"
/*-------------*/
#endif //H_CONFIG
